#
# spec file for package pcsx2
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:          pcsx2
License:       GPL-3.0
Group:         System/Emulators
Version:       1.3.1+git20150603.1258
Release:       2.1
URL:           http://pcsx2.net/
%ifarch x86_64
Summary:       Use i586 package!
%else
Summary:       Sony PlayStation 2 Emulator
%endif
Group:         System/Emulators/Other
Source:        %{name}.tar.xz
#git diff e34477a..origin/master | xz -9 -e >update.diff.xz
Source2:       update.diff.xz
# #git merge origin/clean-gcc-flags
# #git merge origin/atomic
#git diff origin/master..linux-testing
Source4:       linux-testing.xz
#git merge 3kinox/64-bit-clean
#git diff linux-testing..master | xz -9 -e >support_64bit.diff.xz
Source3:       support_64bit.diff.xz
BuildRequires: boost-devel
BuildRequires: cmake
BuildRequires: fdupes
BuildRequires: gcc-c++
BuildRequires: libaio-devel
# non-free library
#BuildRequires: libCg-devel
BuildRequires: libjpeg-devel
%if 0%{?suse_version} > 1230
BuildRequires: Mesa-libGLESv3-devel
%endif
BuildRequires: openSUSE-release
BuildRequires: pkgconfig(alsa)
BuildRequires: pkgconfig(bzip2)
BuildRequires: pkgconfig(egl)
BuildRequires: pkgconfig(glesv2)
BuildRequires: pkgconfig(glew)
BuildRequires: pkgconfig(gtk+-2.0)
BuildRequires: pkgconfig(libsparsehash)
BuildRequires: pkgconfig(sdl)
BuildRequires: pkgconfig(sdl2)
BuildRequires: pkgconfig(soundtouch)
BuildRequires: portaudio-devel
BuildRequires: wxWidgets-devel
BuildRoot:     %{_tmppath}/%{name}-%{version}-build

%description
Sony PlayStation 2 emulator. Requires a BIOS image in %_libdir/%name/bios
or in .%name/bios in your HOME directory (will be created when you first run
PCSX2). Check http://www.pcsx2.net/guide.php#Bios for details on which files
you need and how to obtain them.

%prep
%setup -q -n %{name}
xz -dc %{S:2} | patch --merge -p1 -f
xz -dc %{S:4} | patch --merge -p1 -f
%ifarch x86_64
xz -dc %{S:3} | patch --merge -p1 -f
%endif

#ifarch i586
#sed -i -e "s:rcx:ecx:g" common/src/x86emitter/cpudetect.cpp
#endif
sed -i -e "s:message(FATAL_ERROR \"$:message(WARNING \":g" cmake/BuildParameters.cmake
%ifarch x86_64
sed -i -e "65iint vucycle;" pcsx2/x86/ix86-64/iR5900-64.cpp
%endif

%build
mkdir build
cd build
cmake \
  -DUSER_CMAKE_C_FLAGS='%{optflags}' \
  -DUSER_CMAKE_CXX_FLAGS='%{optflags}' \
  -DCMAKE_INSTALL_PREFIX='%{_prefix}' \
  -DCMAKE_BUILD_TYPE='Release' \
  -DPACKAGE_MODE='TRUE' \
  -DWX28_API='TRUE' \
  -DXDG_STD='TRUE' \
  -DREBUILD_SHADER='TRUE' \
  -DPLUGIN_DIR='%{_libdir}/pcsx2' \
  -DGAMEINDEX_DIR='%{_datadir}/pcsx2' \
  -DDOC_DIR='%{_datadir}/doc/pcsx2' \
  -DBIN_DIR='%{_bindir}' \
  -DGLSL_API='TRUE' \
  -DEXTRA_PLUGINS='TRUE' \
  -DSDL2_API='FALSE' \
  ..
make %{?jobs:-j%{jobs}}
cd ..

%install
cd build
%makeinstall
cd ..

mkdir -p %{buildroot}/%{_docdir}/
mv %{buildroot}/%{_datadir}/doc/pcsx2/ %{buildroot}/%{_docdir}/

# move translations to main language dir if there isn't a sublang or delete
# translations not supported by distro at all
for i in $(ls %{buildroot}%{_datadir}/locale | grep _); do
  new=$(echo $i | sed "s:_.*::g")
  if [ ! -d %{_datadir}/locale/$i ]; then
    if [ -d %{_datadir}/locale/$new ]; then
      mv %{buildroot}%{_datadir}/locale/$i %{buildroot}%{_datadir}/locale/$new
    else
      rm -rf %{buildroot}%{_datadir}/locale/$i
    fi
  fi
done

%fdupes -s %{buildroot}

%files
%defattr(-,root,root)
%{_bindir}/PCSX2*
%{_libdir}/pcsx2
%{_docdir}/pcsx2
%{_datadir}/pcsx2
%{_mandir}/man1/PCSX2.1.gz
%{_datadir}/locale/*/LC_MESSAGES/*.mo
%{_datadir}/applications/PCSX2.desktop
%{_datadir}/pixmaps/PCSX2.xpm

%changelog
* Sun Aug 31 2014 johannesobermayr@gmx.de
- Update to git master
- Fix RPATH/RUNPATH issue the right way
* Fri Mar 21 2014 p.seiler@linuxmail.org
- fixed typo
* Thu Mar 20 2014 p.seiler@linuxmail.org
- changed the way of creating of script file
* Mon Mar  3 2014 p.seiler@linuxmail.org
- add variable to pass through command line parameters to the binary
* Thu Feb  6 2014 p.seiler@linuxmail.org
- removed libegl dependency (not working correctly)
* Thu Feb  6 2014 p.seiler@linuxmail.org
- added libegl dependency
* Thu Feb  6 2014 p.seiler@linuxmail.org
- removed libCg dependency. Used glsl shaders instead
* Wed Feb  5 2014 p.seiler@linuxmail.org
- changed binary name
- added shell script to run binary correctly
* Wed Feb  5 2014 p.seiler@linuxmail.org
- added dependencies for base system and pcsx2 binary
- cleanup -> used cmake to compile
- removed unneeded patch
* Tue Feb  4 2014 p.seiler@linuxmail.org
- initial commit
